@@ -34,7 +34,11 @@
 // Revised: 2/7/2012	ELL
 // Added table prefix handling.
 // Revised: 3/12/2012	ELL
-// Added handling of custom image folder location for background image and list item image. 
+// Added handling of custom image folder location for background image and list item image.
+// Revised: 5/16/2013	ELL
+// Added 2nd and 3rd fonts, box shadow and border radius.
+// Revised: 5/23/2013	ELL
+// Added clear and min/max prefix for width and height.
 //
 
 	if (BWB_BASE_DIR == "")
@@ -53,6 +57,10 @@
 		else $use_table_data = 0;
 		if ($row_bs["font"]) $font = $row_bs["font"];
 		else $font = "-not selected-";
+		if ($row_bs["font2"]) $font2 = $row_bs["font2"];
+		else $font2 = "-not selected-";
+		if ($row_bs["font3"]) $font3 = $row_bs["font3"];
+		else $font3 = "-not selected-";
 		if (!is_null($row_bs["font_size"])) $font_size = $row_bs["font_size"];
 		else $font_size = -1;
 		if ($row_bs["text_color"]) $text_color = $row_bs["text_color"];
@@ -135,10 +143,14 @@
 		else $width = -1;
 		if ($row_bs["width_units"]) $width_units = $row_bs["width_units"];
 		else $width_units = 0;
+		if ($row_bs["width_prefix"]) $width_prefix = $row_bs["width_prefix"];
+		else $width_prefix = "-not selected-";
 		if (!is_null($row_bs["height"])) $height = $row_bs["height"];
 		else $height = -1;
 		if ($row_bs["height_units"]) $height_units = $row_bs["height_units"];
 		else $height_units = 0;
+		if ($row_bs["height_prefix"]) $height_prefix = $row_bs["height_prefix"];
+		else $height_prefix = "-not selected-";
 		if ($row_bs["background_image"]) $background_image = $row_bs["background_image"];
 		else $background_image = "-not selected-";
 		if ($row_bs["background_attachment"]) $background_attachment = $row_bs["background_attachment"];
@@ -223,6 +235,39 @@
 		
 		if ($row_bs["table_layout"]) $table_layout = $row_bs["table_layout"];
 		else $table_layout = "-not selected-";
+		if ($row_bs["clear"]) $clear = $row_bs["clear"];
+		else $clear = "-not selected-";
+		
+		if ($row_bs["radius_top_left"]) $radius_top_left = $row_bs["radius_top_left"];
+		else $radius_top_left = 0;
+		if ($row_bs["radius_top_left_units"]) $radius_top_left_units = $row_bs["radius_top_left_units"];
+		else $radius_top_left_units = 0;
+		if ($row_bs["radius_top_right"]) $radius_top_right = $row_bs["radius_top_right"];
+		else $radius_top_right = 0;
+		if ($row_bs["radius_top_right_units"]) $radius_top_right_units = $row_bs["radius_top_right_units"];
+		else $radius_top_right_units = 0;
+		if ($row_bs["radius_bottom_right"]) $radius_bottom_right = $row_bs["radius_bottom_right"];
+		else $radius_bottom_right = 0;
+		if ($row_bs["radius_bottom_right_units"]) $radius_bottom_right_units = $row_bs["radius_bottom_right_units"];
+		else $radius_bottom_right_units = 0;
+		if ($row_bs["radius_bottom_left"]) $radius_bottom_left = $row_bs["radius_bottom_left"];
+		else $radius_bottom_left = 0;
+		if ($row_bs["radius_bottom_left_units"]) $radius_bottom_left_units = $row_bs["radius_bottom_left_units"];
+		else $radius_bottom_left_units = 0;
+		
+		if (isset($row_bs["box_shadow_horizontal"])) $box_shadow_horizontal = $row_bs["box_shadow_horizontal"];
+		else $box_shadow_horizontal = -1000000;
+		if (isset($row_bs["box_shadow_vertical"])) $box_shadow_vertical = $row_bs["box_shadow_vertical"];
+		else $box_shadow_vertical = -1000000;
+		if (isset($row_bs["box_shadow_blur"])) $box_shadow_blur = $row_bs["box_shadow_blur"];
+		else $box_shadow_blur = -1;
+		if (isset($row_bs["box_shadow_spread"])) $box_shadow_spread = $row_bs["box_shadow_spread"];
+		else $box_shadow_spread = -1000000;
+		if (isset($row_bs["box_shadow_color"])) $box_shadow_color = $row_bs["box_shadow_color"];
+		else $box_shadow_color = "-not set-";
+		if (isset($row_bs["box_shadow_inset"])) $box_shadow_inset = $row_bs["box_shadow_inset"];
+		else $box_shadow_inset = 0;
+		
 		//////////////////////////////////////////////////////////////////
 	
 		if ($use_table_data == 1)
@@ -230,7 +275,17 @@
 			$css_string .= $class . " {\n";
 				
 			if ($font != "-not selected-")
-				$css_string .= "   font-family: " . $font . ";\n";
+			{
+				$css_string .= "   font-family: " . $font;
+				if ($font2 != "-not selected-")
+				{
+					$css_string .= ", " . $font2;
+					if ($font3 != "-not selected-")
+						$css_string .= ", " . $font3;
+				}
+				$css_string .= ";\n";
+			}
+				
 			if ($font_size != -1)
 				$css_string .= "   font-size: " . $font_size . "px;\n";
 			if ($text_color != "-not set-")
@@ -309,6 +364,8 @@
 			{
 				$css_string .= "   filter: alpha(opacity=" . $bkgd_opacity . ");\n";
 				$css_string .= "   -moz-opacity: " . $bkgd_opacity . "%;\n";
+				$bkgd_opacity = $bkgd_opacity/100;
+				$css_string .= "   opacity: " . $bkgd_opacity . ";\n";
 			}
 			
 			if ($border > -1)
@@ -494,17 +551,27 @@
 				
 			if ($width != -1)
 			{
-				if ($width_units == 0)
-					$css_string .= "   width: " . $width . "px;\n";
+				if ($width_prefix == "-not selected-")
+					$prefix = "";
 				else
-					$css_string .= "   width: " . $width . "%;\n";
+					$prefix = $width_prefix . "-";
+					
+				if ($width_units == 0)
+					$css_string .= "   " . $prefix . "width: " . $width . "px;\n";
+				else
+					$css_string .= "   " .  $prefix . "width: " . $width . "%;\n";
 			}
 			if ($height != -1)
 			{
-				if ($height_units == 0)
-					$css_string .= "   height: " . $height . "px;\n";
+				if ($height_prefix == "-not selected-")
+					$prefix = "";
 				else
-					$css_string .= "   height: " . $height . "%;\n";
+					$prefix = $height_prefix . "-";
+					
+				if ($height_units == 0)
+					$css_string .= "   " . $prefix . "height: " . $height . "px;\n";
+				else
+					$css_string .= "   " . $prefix . "height: " . $height . "%;\n";
 			}
 			
 			if (($background_image != "-not set-") && ($background_image != "-not selected-") && ($background_image != ""))
@@ -532,6 +599,51 @@
 				
 			if ($table_layout != "-not selected-")
 				$css_string .= "   table-layout: " . $table_layout . ";\n";
+			if ($clear != "-not selected-")
+				$css_string .= "   clear: " . $clear . ";\n";
+				
+			if ($radius_top_left > 0)
+			{
+				if ($radius_top_left_units == 0)
+					$css_string .= "   border-top-left-radius: " . $radius_top_left . "px;\n";
+				else
+					$css_string .= "   border-top-left-radius: " . $radius_top_left . "%;\n";
+			}
+			if ($radius_top_right > 0)
+			{
+				if ($radius_top_right_units == 0)
+					$css_string .= "   border-top-right-radius: " . $radius_top_right . "px;\n";
+				else
+					$css_string .= "   border-top-right-radius: " . $radius_top_right . "%;\n";
+			}
+			if ($radius_bottom_right > 0)
+			{
+				if ($radius_bottom_right_units == 0)
+					$css_string .= "   border-bottom-right-radius: " . $radius_bottom_right . "px;\n";
+				else
+					$css_string .= "   border-bottom-right-radius: " . $radius_bottom_right . "%;\n";
+			}
+			if ($radius_bottom_left > 0)
+			{
+				if ($radius_bottom_left_units == 0)
+					$css_string .= "   border-bottom-left-radius: " . $radius_bottom_left . "px;\n";
+				else
+					$css_string .= "   border-bottom-left-radius: " . $radius_bottom_left . "%;\n";
+			}
+			
+			if ($box_shadow_horizontal != -1000000)
+			{
+				$css_string .= "   box-shadow: " . $box_shadow_horizontal . "px " . $box_shadow_vertical . "px";
+				if ($box_shadow_blur > -1)
+					$css_string .= " " . $box_shadow_blur . "px";
+				if ($box_shadow_spread != -1000000)
+					$css_string .= " " . $box_shadow_spread . "px";
+				if (isset($box_shadow_color) && ($box_shadow_color != "-not set-"))
+					$css_string .= " " . $box_shadow_color;
+				if ($box_shadow_inset == 1)
+					$css_string .= " inset";
+				$css_string .= ";\n";
+			}
 			
 			$css_string .= "}\n\n";
 		} // end if use table data for tag
