@@ -24,6 +24,10 @@
 // Added table prefix handling.  Added reference to user files folder constant.
 // Revised: 11/8/2012	ELL
 // Added injection of current color for initializing color picker.
+// Revised: 5/16/2013	ELL
+// Added 2nd and 3rd fonts, box shadow and border radius.
+// Revised: 5/23/2013	ELL
+// Added clear, min/max prefix for width and height and sticky footer setup button.
 // 
 //
 	include ("check_session.php");
@@ -75,6 +79,8 @@ function PopulateForm(class_select)
 				document.getElementById("use_table_data").checked = false;
 				
 				document.getElementById("font").value = "-not selected-";
+				document.getElementById("font2").value = "-not selected-";
+				document.getElementById("font3").value = "-not selected-";
 				document.getElementById("font_size").value = -1;
 				document.getElementById("text_color").value = "-not set-";
 				document.getElementById("align").value = "-not selected-";
@@ -117,8 +123,10 @@ function PopulateForm(class_select)
 
 				document.getElementById("width").value = -1;
 				document.getElementById("width_units").value = 0;
+				document.getElementById("width_prefix").value = "-not selected-";
 				document.getElementById("height").value = -1;
 				document.getElementById("height_units").value = 0;
+				document.getElementById("height_prefix").value = "-not selected-";
 				document.getElementById("background_image_select").value = "-not selected-";
 				document.getElementById("background_image").value = "-not selected-";
 				document.getElementById("background_attachment").value = "-not selected-";
@@ -165,6 +173,23 @@ function PopulateForm(class_select)
 				document.getElementById("list_style_image").value = "-not selected-";
 		
 				document.getElementById("table_layout").value = "-not selected-";
+				document.getElementById("clear").value = "-not selected-";
+				
+				document.getElementById("radius_top_left").value = 0;
+				document.getElementById("radius_top_left_units").value = 0;
+				document.getElementById("radius_top_right").value = 0;
+				document.getElementById("radius_top_right_units").value = 0;
+				document.getElementById("radius_bottom_right").value = 0;
+				document.getElementById("radius_bottom_right_units").value = 0;
+				document.getElementById("radius_bottom_left").value = 0;
+				document.getElementById("radius_bottom_left_units").value = 0;
+				
+				document.getElementById("box_shadow_horizontal").value = -1000000;
+				document.getElementById("box_shadow_vertical").value = -1000000;
+				document.getElementById("box_shadow_blur").value = -1;
+				document.getElementById("box_shadow_spread").value = -1000000;
+				document.getElementById("box_shadow_color").value = "-not set-";
+				document.getElementById("box_shadow_inset").checked = false;
 			}
 			else
 			{
@@ -175,6 +200,8 @@ function PopulateForm(class_select)
 				else
 					document.getElementById("use_table_data").checked = false;
 				document.getElementById("font").value = JSON_row.font;
+				document.getElementById("font2").value = JSON_row.font2;
+				document.getElementById("font3").value = JSON_row.font3;
 				document.getElementById("font_size").value = JSON_row.font_size;
 				document.getElementById("text_color").value = JSON_row.text_color;
 				document.getElementById("align").value = JSON_row.align;
@@ -256,8 +283,10 @@ function PopulateForm(class_select)
 
 				document.getElementById("width").value = JSON_row.width;
 				document.getElementById("width_units").value = JSON_row.width_units;
+				document.getElementById("width_prefix").value = JSON_row.width_prefix;
 				document.getElementById("height").value = JSON_row.height;
 				document.getElementById("height_units").value = JSON_row.height_units;
+				document.getElementById("height_prefix").value = JSON_row.height_prefix;
 				document.getElementById("background_image_select").value = JSON_row.background_image_select;
 				document.getElementById("background_image").value = JSON_row.background_image;
 				document.getElementById("background_attachment").value = JSON_row.background_attachment;
@@ -316,6 +345,26 @@ function PopulateForm(class_select)
 				document.getElementById("list_style_image").value = JSON_row.list_style_image;
 		
 				document.getElementById("table_layout").value = JSON_row.table_layout;
+				document.getElementById("clear").value = JSON_row.clear;
+				
+				document.getElementById("radius_top_left").value = JSON_row.radius_top_left;
+				document.getElementById("radius_top_left_units").value = JSON_row.radius_top_left_units;
+				document.getElementById("radius_top_right").value = JSON_row.radius_top_right;
+				document.getElementById("radius_top_right_units").value = JSON_row.radius_top_right_units;
+				document.getElementById("radius_bottom_right").value = JSON_row.radius_bottom_right;
+				document.getElementById("radius_bottom_right_units").value = JSON_row.radius_bottom_right_units;
+				document.getElementById("radius_bottom_left").value = JSON_row.radius_bottom_left;
+				document.getElementById("radius_bottom_left_units").value = JSON_row.radius_bottom_left_units;
+				
+				document.getElementById("box_shadow_horizontal").value = JSON_row.box_shadow_horizontal;
+				document.getElementById("box_shadow_vertical").value = JSON_row.box_shadow_vertical;
+				document.getElementById("box_shadow_blur").value = JSON_row.box_shadow_blur;
+				document.getElementById("box_shadow_spread").value = JSON_row.box_shadow_spread;
+				document.getElementById("box_shadow_color").value = JSON_row.box_shadow_color;
+				if (JSON_row.box_shadow_inset == 1)
+					document.getElementById("box_shadow_inset").checked = true;
+				else
+					document.getElementById("box_shadow_inset").checked = false;
 				
 			}
 			var heading_str = document.getElementById("goto_class").value;
@@ -383,6 +432,8 @@ function UpdateCSS()
 		if (document.getElementById("use_table_data").checked == true) params = params + "&use_table_data=1";
 		else params = params + "&use_table_data=0";
 		params = params + "&font=" + document.getElementById("font").value;
+		params = params + "&font2=" + document.getElementById("font2").value;
+		params = params + "&font3=" + document.getElementById("font3").value;
 		params = params + "&font_size=" + document.getElementById("font_size").value;
 		params = params + "&text_color=" + document.getElementById("text_color").value;
 		params = params + "&align=" + document.getElementById("align").value;
@@ -456,8 +507,10 @@ function UpdateCSS()
 		else params = params + "&margin_bottom_auto=0";
 		params = params + "&width=" + document.getElementById("width").value;
 		params = params + "&width_units=" + document.getElementById("width_units").value;
+		params = params + "&width_prefix=" + document.getElementById("width_prefix").value;
 		params = params + "&height=" + document.getElementById("height").value;
 		params = params + "&height_units=" + document.getElementById("height_units").value;
+		params = params + "&height_prefix=" + document.getElementById("height_prefix").value;
 		
 		params = params + "&position=" + document.getElementById("position").value;
 		params = params + "&position_left=" + document.getElementById("position_left").value;
@@ -495,6 +548,25 @@ function UpdateCSS()
 		params = params + "&list_style_image=" + document.getElementById("list_style_image").value;
 		
 		params = params + "&table_layout=" + document.getElementById("table_layout").value;
+		params = params + "&clear=" + document.getElementById("clear").value;
+		
+		params = params + "&radius_top_left=" + document.getElementById("radius_top_left").value;
+		params = params + "&radius_top_left_units=" + document.getElementById("radius_top_left_units").value;
+		params = params + "&radius_top_right=" + document.getElementById("radius_top_right").value;
+		params = params + "&radius_top_right_units=" + document.getElementById("radius_top_right_units").value;
+		params = params + "&radius_bottom_right=" + document.getElementById("radius_bottom_right").value;
+		params = params + "&radius_bottom_right_units=" + document.getElementById("radius_bottom_right_units").value;
+		params = params + "&radius_bottom_left=" + document.getElementById("radius_bottom_left").value;
+		params = params + "&radius_bottom_left_units=" + document.getElementById("radius_bottom_left_units").value;
+		
+		params = params + "&box_shadow_horizontal=" + document.getElementById("box_shadow_horizontal").value;
+		params = params + "&box_shadow_vertical=" + document.getElementById("box_shadow_vertical").value;
+		params = params + "&box_shadow_blur=" + document.getElementById("box_shadow_blur").value;
+		params = params + "&box_shadow_spread=" + document.getElementById("box_shadow_spread").value;
+		params = params + "&box_shadow_color=" + document.getElementById("box_shadow_color").value;
+		if (document.getElementById("box_shadow_inset").checked == true) params = params + "&box_shadow_inset=1";
+		else params = params + "&box_shadow_inset=0";
+		
 //			alert(params);
 		
 		xmlhttp.send(params);
@@ -504,7 +576,7 @@ function UpdateCSS()
 
 </head>
 
-<body onLoad="enable_disable_controls(0);">
+<body>
 <div align="center">
 <table border="0" width="90%">
  <tr>
@@ -581,16 +653,44 @@ function UpdateCSS()
 					  <td align="right">Font: </td>
 					  <td colspan="3">
 					      <select name="font" id="font">
+                          	<option value='-not selected-'>-not selected-</option>
 					      <?php
-						  	echo "<option value='-not selected-'";
-							echo ">-not selected-</option>\n";
-							
+						  $fonts = array();
 						  $query = "SELECT * FROM " . BWB_TABLE_PREFIX . "fonts ORDER BY font";
 						  $result = $bwb_dbh->query($query);
 						  while ($row = $result->fetch(PDO::FETCH_ASSOC))
+							$fonts[$row['font']] = $row['websafe'];
+						  
+						  foreach ($fonts as $tmp_font => $tmp_websafe)
+						  {
+							echo "<option value='$tmp_font'";
+							echo " style='font-family:$tmp_font;'>$tmp_font";
+							if ($tmp_websafe == 1)
+								echo " &nbsp; &nbsp; &nbsp; &radic;";
+							echo "</option>\n";
+						  }
+					      ?>
+					      </select>
+                          
+                           <select name="font2" id="font2">
+                           	<option value='-not selected-'>-not selected-</option>
+					      <?php							
+						  foreach ($fonts as $tmp_font => $tmp_websafe)
+						  {
+							echo "<option value='$tmp_font'";
+							echo " style='font-family:$tmp_font;'>$tmp_font";
+							if ($tmp_websafe == 1)
+								echo " &nbsp; &nbsp; &nbsp; &radic;";
+							echo "</option>\n";
+						  }
+					      ?>
+					      </select>
+                          
+                           <select name="font3" id="font3">
+                           	<option value='-not selected-'>-not selected-</option>
+					      <?php							
+						  foreach ($fonts as $tmp_font => $tmp_websafe)
 						  {
-							$tmp_font = $row['font'];
-							$tmp_websafe = $row['websafe'];
 							echo "<option value='$tmp_font'";
 							echo " style='font-family:$tmp_font;'>$tmp_font";
 							if ($tmp_websafe == 1)
@@ -790,11 +890,18 @@ function UpdateCSS()
                          <option value="auto">Auto</option>
                          <option value="fixed">Fixed</option>
                          <option value="inherit">Inherit</option>
-					     </select>
+					   </select>
                        </td>
-					   <td align="right">&nbsp;</td>
-					   <td>&nbsp;
-                       
+					   <td align="right">Clear: </td>
+					   <td>
+                       <select name="clear" id="clear">
+					     <option value="-not selected-">-not selected-</option>
+                         <option value="left">Left</option>
+                         <option value="right">Right</option>
+                         <option value="both">Both</option>
+                         <option value="none">None</option>
+                         <option value="inherit">Inherit</option>
+					   </select>
 					   </td>
 				     </tr>
 			       </table>
@@ -891,6 +998,44 @@ function UpdateCSS()
 					   <td align="right">Left:</td>
                        <td>
                        <input name="padding_left" type="text" id="padding_left" value="" size="6"> px
+                       </td>
+				     </tr>
+                  </table>
+                  <table  width="100%" border="0">
+                     <tr>
+					   <td align="right" class="bold">Radius</td>
+					   <td align="right">
+                       Top Left: </td>					  
+					   <td>
+                       <input type="text" name="radius_top_left" id="radius_top_left" value="" size="6">
+                       <select name="radius_top_left_units" id="radius_top_left_units">
+                        <option value="0">px</option>
+                        <option value="1">%</option>
+                       </select> 
+                       </td>
+					   <td align="right">Top Right: </td>
+					   <td>
+                       <input type="text" name="radius_top_right" id="radius_top_right" value="" size="6">
+                       <select name="radius_top_right_units" id="radius_top_right_units">
+                        <option value="0">px</option>
+                        <option value="1">%</option>
+                       </select> 
+                       </td>
+					   <td align="right">Bottom Right: </td>
+					   <td>
+                       <input type="text" name="radius_bottom_right" id="radius_bottom_right" value="" size="6">
+                       <select name="radius_bottom_right_units" id="radius_bottom_right_units">
+                        <option value="0">px</option>
+                        <option value="1">%</option>
+                       </select> 
+                       </td>
+					   <td align="right">Bottom Left: </td>
+                       <td>
+                       <input type="text" name="radius_bottom_left" id="radius_bottom_left" value="" size="6">
+                       <select name="radius_bottom_left_units" id="radius_bottom_left_units">
+                        <option value="0">px</option>
+                        <option value="1">%</option>
+                       </select> 
                        </td>
 				     </tr>
 			       </table>
@@ -953,6 +1098,11 @@ function UpdateCSS()
                           <option value="0">px</option>
                           <option value="1">%</option>
 					     </select>
+                         <select name="width_prefix" id="width_prefix">
+                          <option value="-not selected-"></option>
+                          <option value="min">Min</option>
+                          <option value="max">Max</option>
+					     </select>
                        </td>
 				     </tr>
                      <tr>
@@ -983,6 +1133,11 @@ function UpdateCSS()
                           <option value="0">px</option>
                           <option value="1">%</option>
 					     </select>
+                         <select name="height_prefix" id="height_prefix">
+                          <option value="-not selected-"></option>
+                          <option value="min">Min</option>
+                          <option value="max">Max</option>
+					     </select>
 					   </td>
                      </tr>
 			       </table>
@@ -1330,6 +1485,32 @@ function UpdateCSS()
 			   </tr>
 	         </table>
 
+			<table border="1" width="100%">
+              <tr>
+                <td>
+                <table border="0" width="100%">
+                  <tr>
+                    <td class="bold" colspan="12">Box Shadow</td>
+                  </tr>
+                  <tr>
+                    <td align="right">Horizontal Offset: </td>
+                    <td><input type="text" name="box_shadow_horizontal" id="box_shadow_horizontal" value="" size="6" /></td>
+                    <td align="right">Vertical Offset: </td>
+                    <td><input type="text" name="box_shadow_vertical" id="box_shadow_vertical" value="" size="6" /></td>
+                    <td align="right">Blur: </td>
+                    <td><input type="text" name="box_shadow_blur" id="box_shadow_blur" value="" size="6" /></td>
+                    <td align="right">Spread: </td>
+                    <td><input type="text" name="box_shadow_spread" id="box_shadow_spread" value="" size="6" /></td>
+                    <td align="right">Color: </td>
+                    <td><input type="text" name="box_shadow_color" id="box_shadow_color" value="" size="6" onBlur="CheckColorString(this);" />
+                     <span class="small_message"> <a href=# onClick="javascript: popupcolorpicker('frm_site_styles', 'box_shadow_color');">#RRGGBB</a></span></td>
+                    <td align="right">Inset: </td>
+                    <td><input type="checkbox" name="box_shadow_inset" id="box_shadow_inset" value="1" /></td>
+                  </tr>
+                </table>
+                </td>
+              </tr>
+            </table>
              
 	 </td></tr></table>
      </td>
@@ -1367,6 +1548,7 @@ function UpdateCSS()
 		  ?>
            <td align="center">
          		<input type="button" name="load_center_params" id="load_center_params" value="Setup For Centered Pages" onClick="LoadCenterParams();">
+                <input type="button" name="load_sticky_footer_params" id="load_sticky_footer_params" value="Setup For Sticky Footer" onClick="LoadStickyFooterParams();">
            </td>
            <?php
 			}
@@ -1388,9 +1570,7 @@ function UpdateCSS()
 	 
        <table width="100%" border="0" cellspacing="0" cellpadding="0">
          <tr>
-	       <td>&nbsp;
-             
-           </td>
+	       <td>&nbsp;</td>
 	     </tr>
          <tr>
 		   <td align="center">
@@ -1410,6 +1590,7 @@ function UpdateCSS()
 </div>
 
 <script language="javascript" type="text/javascript">
+	enable_disable_controls(0);
 	HideStatusMsg();
 </script>
 </body>
