@@ -14,6 +14,10 @@
 // border styles.
 // Revised: 2/9/2012	ELL
 // Added table prefix handling.  Added references to CSS folder configurations.
+// Revised: 5/16/2013	ELL
+// Added 2nd and 3rd fonts, box shadow and border radius.
+// Revised: 5/23/2013	ELL
+// Added clear and min/max prefix for width and height.
 //
 //
 	include ("check_session.php");
@@ -50,6 +54,8 @@
 			$sub_class_of = $row["sub_class_of"];
 			$use_table_data = $row["use_table_data"];
 			$font = $row["font"];
+			$font2 = $row["font2"];
+			$font3 = $row["font3"];
 			$font_size = $row["font_size"];
 			$text_color = $row["text_color"];
 			$padding_top = $row["padding_top"];
@@ -101,8 +107,10 @@
 			$margin_bottom_auto = $row["margin_bottom_auto"];
 			$width = $row["width"];
 			$width_units = $row["width_units"];
+			$width_prefix = $row["width_prefix"];
 			$height = $row["height"];
 			$height_units = $row["height_units"];
+			$height_prefix = $row["height_prefix"];
 			
 			$background_image = $row["background_image"];
 			$background_attachment = $row["background_attachment"];
@@ -139,20 +147,40 @@
 			$list_style_image = $row["list_style_image"];
 			
 			$table_layout = $row["table_layout"];
-				
+			$clear = $row["clear"];
+			
+			$radius_top_left = $row["radius_top_left"];
+			$radius_top_left_units = $row["radius_top_left_units"];
+			$radius_top_right = $row["radius_top_right"];
+			$radius_top_right_units = $row["radius_top_right_units"];
+			$radius_bottom_right = $row["radius_bottom_right"];
+			$radius_bottom_right_units = $row["radius_bottom_right_units"];
+			$radius_bottom_left = $row["radius_bottom_left"];
+			$radius_bottom_left_units = $row["radius_bottom_left_units"];
+			
+			$box_shadow_horizontal = $row["box_shadow_horizontal"];
+			$box_shadow_vertical = $row["box_shadow_vertical"];
+			$box_shadow_blur = $row["box_shadow_blur"];
+			$box_shadow_spread = $row["box_shadow_spread"];
+			$box_shadow_color = $row["box_shadow_color"];
+			$box_shadow_inset = $row["box_shadow_inset"];
+
 			//Insert new data into table.
 		$insert_key = "class='" . $class . "', ";
 		
-		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
-		$display, $width, $width_units, $height, $height_units, $position, $position_left, $position_left_units, $position_top, $position_top_units,
+		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix,
+		$position, $position_left, $position_left_units, $position_top, $position_top_units,
 		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
-		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
+		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear, 
+		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units);
 		 
 		 	$cnt = $bwb_dbh->exec($query2);
 		} // end while
@@ -202,6 +230,10 @@
 	else $use_table_data = 0;
 	if ($_POST["font"]) $font = $_POST["font"];
 	else $font = "-not selected-";
+	if ($_POST["font2"]) $font2 = $_POST["font2"];
+	else $font2 = "-not selected-";
+	if ($_POST["font3"]) $font3 = $_POST["font3"];
+	else $font3 = "-not selected-";
 	if ($_POST["font_size"]) $font_size = $_POST["font_size"];
 	else $font_size = -1;
 	if ($_POST["text_color"]) $text_color = $_POST["text_color"];
@@ -276,10 +308,14 @@
 	else $width = -1;
 	if ($_POST["width_units"]) $width_units = $_POST["width_units"];
 	else $width_units = 0;
+	if ($_POST["width_prefix"]) $width_prefix = $_POST["width_prefix"];
+	else $width_prefix = "";
 	if (is_numeric($_POST["height"])) $height = $_POST["height"];
 	else $height = -1;
 	if ($_POST["height_units"]) $height_units = $_POST["height_units"];
 	else $height_units = 0;
+	if ($_POST["height_prefix"]) $height_prefix = $_POST["height_prefix"];
+	else $height_prefix = "";
 	if ($_POST["background_image"]) $background_image = $_POST["background_image"];
 	else $background_image = "-not selected-";
 	if ($_POST["background_attachment"]) $background_attachment = $_POST["background_attachment"];
@@ -372,43 +408,96 @@
 	
 	if ($_POST["table_layout"]) $table_layout = $_POST["table_layout"];
 	else $table_layout = "-not selected-";
+	if ($_POST["clear"]) $clear = $_POST["clear"];
+	else $clear = "-not selected-";
+
+	if ($_POST["radius_top_left"]) $radius_top_left = $_POST["radius_top_left"];
+	else $radius_top_left = 0;
+	if ($_POST["radius_top_left_units"]) $radius_top_left_units = $_POST["radius_top_left_units"];
+	else $radius_top_left_units = 0;
+	if ($_POST["radius_top_right"]) $radius_top_right = $_POST["radius_top_right"];
+	else $radius_top_right = 0;
+	if ($_POST["radius_top_right_units"]) $radius_top_right_units = $_POST["radius_top_right_units"];
+	else $radius_top_right_units = 0;
+	if ($_POST["radius_bottom_right"]) $radius_bottom_right = $_POST["radius_bottom_right"];
+	else $radius_bottom_right = 0;
+	if ($_POST["radius_bottom_right_units"]) $radius_bottom_right_units = $_POST["radius_bottom_right_units"];
+	else $radius_bottom_right_units = 0;
+	if ($_POST["radius_bottom_left"]) $radius_bottom_left = $_POST["radius_bottom_left"];
+	else $radius_bottom_left = 0;
+	if ($_POST["radius_bottom_left_units"]) $radius_bottom_left_units = $_POST["radius_bottom_left_units"];
+	else $radius_bottom_left_units = 0;
+	
+	if ($_POST["box_shadow_horizontal"]) $box_shadow_horizontal = $_POST["box_shadow_horizontal"];
+	else $box_shadow_horizontal = -1000000;
+	if ($_POST["box_shadow_vertical"]) $box_shadow_vertical = $_POST["box_shadow_vertical"];
+	else $box_shadow_vertical = -1000000;
+	if ($_POST["box_shadow_blur"]) $box_shadow_blur = $_POST["box_shadow_blur"];
+	else $box_shadow_blur = -1;
+	if ($_POST["box_shadow_spread"]) $box_shadow_spread = $_POST["box_shadow_spread"];
+	else $box_shadow_spread = -1000000;
+	if ($_POST["box_shadow_color"]) $box_shadow_color = $_POST["box_shadow_color"];
+	else $box_shadow_color = "-not set-";
+	if ($_POST["box_shadow_inset"]) $box_shadow_inset = $_POST["box_shadow_inset"];
+	else $box_shadow_inset = 0;
 	
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '" . $class . "'";
 	$result = $bwb_dbh->query($query);
 	$row_count = $result->rowCount();
 	
+	if (($_POST['quick_setup'] == 1) && ($row_count > 0))
+	{
+		$fields = array("align", "vertical_align", "bkgd_color", "position", "position_bottom", "position_bottom_units", "position_top", "position_top_units", "position_right", "position_right_units", "position_left", "position_left_units", "width", "width_units", "width_prefix", "height", "height_units", "height_prefix", "margin_left","margin_left_units", "margin_left_auto", "margin_right", "margin_right_units", "margin_right_auto", "margin_top", "margin_top_units", "margin_top_auto", "margin_bottom", "margin_bottom_units", "margin_bottom_auto", "overflow", "display", "clear");
 		
-	if ($row_count > 0)
+		$query = "UPDATE `" . BWB_TABLE_PREFIX . $site_css_table . "` SET `use_table_data`=1, ";
+		$delim = "";
+		foreach ($_POST as $key => $val)
+		{
+			if (in_array($key, $fields))
+			{
+				$query .= $delim . "`" . $key . "`='" . $val . "'";
+				$delim = ", ";
+			}
+		}
+		$query .= " WHERE `class` = '" . $class . "'";
+	}
+	elseif ($row_count > 0)
 	{
 		//Update class record.
 		$condition = "`class` = '" . $class . "'";
 		
-		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", $use_table_data, $font, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
-		$display, $width, $width_units, $height, $height_units, $position, $position_left, $position_left_units, $position_top, $position_top_units,
+		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix,
+		$position, $position_left, $position_left_units, $position_top, $position_top_units,
 		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
-		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
+		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear,
+		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units);
 	}
 	else
 	{
 		//Insert new data into table.
 		$insert_key = "class='" . $class . "', ";
 		
-		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
-		$display, $width, $width_units, $height, $height_units, $position, $position_left, $position_left_units, $position_top, $position_top_units,
+		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix, 
+		$position, $position_left, $position_left_units, $position_top, $position_top_units,
 		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
-		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
+		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear,
+		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units);
 	}
 //	echo $query;
 	$cnt = $bwb_dbh->exec($query);
