@@ -21,6 +21,8 @@
 // Renamed z-index, overflow and clip vars to not have prepended "position_".
 // Revised: 2/10/2012	ELL
 // Added table prefix handling.  Added references to CSS folder configuration.
+// Revised: 5/23/2013	ELL
+// Added clear and min/max prefix for width and height.
 //
 	include ("check_session.php");
 		
@@ -43,6 +45,8 @@
 		$sub_class_of = $row["sub_class_of"];
 		$use_table_data = $row["use_table_data"];
 		$font = $row["font"];
+		$font2 = $row["font2"];
+		$font3 = $row["font3"];
 		$font_size = $row["font_size"];
 		$text_color = $row["text_color"];
 		$padding_top = $row["padding_top"];
@@ -85,8 +89,10 @@
 		$display = $row["display"];
 		$width = $row["width"];
 		$width_units = $row["width_units"];
+		$width_prefix = $row["width_prefix"];
 		$height = $row["height"];
 		$height_units = $row["height_units"];
+		$height_prefix = $row["height_prefix"];
 		$background_image = $row["background_image"];
 		$background_attachment = $row["background_attachment"];
 		$background_repeat = $row["background_repeat"];
@@ -131,6 +137,23 @@
 		$list_style_image = $row["list_style_image"];
 		
 		$table_layout = $row["table_layout"];
+		$clear = $row["clear"];
+		
+		$radius_top_left = $row["radius_top_left"];
+		$radius_top_left_units = $row["radius_top_left_units"];
+		$radius_top_right = $row["radius_top_right"];
+		$radius_top_right_units = $row["radius_top_right_units"];
+		$radius_bottom_right = $row["radius_bottom_right"];
+		$radius_bottom_right_units = $row["radius_bottom_right_units"];
+		$radius_bottom_left = $row["radius_bottom_left"];
+		$radius_bottom_left_units = $row["radius_bottom_left_units"];
+		
+		$box_shadow_horizontal = $row["box_shadow_horizontal"];
+		$box_shadow_vertical = $row["box_shadow_vertical"];
+		$box_shadow_blur = $row["box_shadow_blur"];
+		$box_shadow_spread = $row["box_shadow_spread"];
+		$box_shadow_color = $row["box_shadow_color"];
+		$box_shadow_inset = $row["box_shadow_inset"];
 		
 		$query2 = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $css_table . " WHERE `class` = '" . $class . "'";
 		$result2 = $bwb_dbh->query($query2);
@@ -141,32 +164,38 @@
 			//Update class record.
 			$condition = "`class` = '" . $class . "'";
 
-		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $css_table, "UPDATE", $condition, "", $use_table_data, $font, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $css_table, "UPDATE", $condition, "", $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
-		$display, $width, $width_units, $height, $height_units, $position, $position_left, $position_left_units, $position_top, $position_top_units,
+		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix,
+		$position, $position_left, $position_left_units, $position_top, $position_top_units,
 		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
-		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
+		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear,
+		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units);
 		}
 		else
 		{
 			//Insert new data into table. 
 		$insert_key = "class='" . $class . "', ";
 
-		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
+		$query2 = BuildSQLString(BWB_TABLE_PREFIX . $css_table, "INSERT INTO", "", $insert_key, $use_table_data, $font, $font2, $font3, $font_size, $text_color, $padding_top, $padding_right, $padding_bottom, $padding_left, $weight, $italic,
 		$underline, $overline, $blink, $linethrough, $font_stretch, $oblique, $small_caps, $no_text_decoration, $shadow, $shadow_color, $shadow_x_offset,
 		$shadow_y_offset, $shadow_blur, $line_height, $line_height_units, $align, $vertical_align, $bkgd_color, $bkgd_opacity, $border, $border_color,
 		$border_style, $outline_style, $border_collapse, $border_sides, $margin_top, $margin_top_units, $margin_top_auto, $margin_right, $margin_right_units,
 		$margin_right_auto, $margin_left, $margin_left_units, $margin_left_auto, $margin_bottom, $margin_bottom_units, $margin_bottom_auto,
-		$display, $width, $width_units, $height, $height_units, $position, $position_left, $position_left_units, $position_top, $position_top_units,
+		$display, $width, $width_units, $width_prefix, $height, $height_units, $height_prefix,
+		$position, $position_left, $position_left_units, $position_top, $position_top_units,
 		$position_right, $position_right_units, $position_bottom, $position_bottom_units, $z_index, $overflow,
 		$clip_top, $clip_top_units, $clip_right, $clip_right_units, $clip_bottom, $clip_bottom_units, $clip_left, $clip_left_units,
 		$background_image, $background_attachment, $background_repeat, $background_position, $background_position_x, $background_position_y,
-		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout);
+		$background_position_units, $list_style_type, $list_style_position, $list_style_image, $float, $white_space, $table_layout, $clear,
+		$box_shadow_horizontal, $box_shadow_vertical, $box_shadow_blur, $box_shadow_spread, $box_shadow_color, $box_shadow_inset, $radius_top_left,
+		$radius_top_left_units, $radius_top_right, $radius_top_right_units, $radius_bottom_right, $radius_bottom_right_units, $radius_bottom_left, $radius_bottom_left_units);
 		}
 
 		$cnt = $bwb_dbh->exec($query2);
