@@ -4,6 +4,10 @@
 // Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created:	3/9/2013	ELL
+// Revised: 5/14/2013	ELL
+// Added prepend and postpend for header and footer.
+// Revised: 5/23/2013	ELL
+// Changed header and footer prepend and postpend to HTML 5 tags.
 
 	include ("check_session.php");
 		
@@ -59,22 +63,25 @@
 		//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%//
 		
 		// Because of unpredictable behavior as to where CKeditor allows added on content for new pages, need to dig content out of top of page.
-		$sValue_arr[0] = str_replace("<div class='wrap' id='wrap'>", "", $sValue_arr[0], $count);
-		$sValue_arr[0] = str_replace("<div class=\"wrap\" id=\"wrap\">", "", $sValue_arr[0], $count);
-		$sValue_arr[0] = str_replace("<div id='wrap' class='wrap'>", "", $sValue_arr[0], $count);
-		$sValue_arr[0] = str_replace("<div id=\"wrap\" class=\"wrap\">", "", $sValue_arr[0], $count);
-		if (strpos($sValue_arr[0], "<table width='100%' height='100%'>") !== false)
-			$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table width='100%' height='100%'>"), strlen("<table width='100%' height='100%'>"));
-		if (strpos($sValue_arr[0], "<table width=\"100%\" height=\"100%\">") !== false)
-			$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table width=\"100%\" height=\"100%\">"), strlen("<table width=\"100%\" height=\"100%\">"));
-		if (strpos($sValue_arr[0], "<table height='100%' width='100%'>") !== false)
-			$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table height='100%' width='100%'>"), strlen("<table height='100%' width='100%'>"));
-		if (strpos($sValue_arr[0], "<table height=\"100%\" width=\"100%\">") !== false)
-			$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table height=\"100%\" width=\"100%\">"), strlen("<table height=\"100%\" width=\"100%\">"));
-		if (strpos($sValue_arr[0], "<tbody>") !== false)
-			$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<tbody>"), strlen("<tbody>"));
-		if (strpos($sValue_arr[0], "<tr>") !== false)
-			$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<tr>"), strlen("<tr>"));
+		if ( (substr($page_name, 0, 6) != "header") && (substr($page_name, 0, 6) != "footer") )
+		{
+			$sValue_arr[0] = str_replace("<div class='wrap' id='wrap'>", "", $sValue_arr[0], $count);
+			$sValue_arr[0] = str_replace("<div class=\"wrap\" id=\"wrap\">", "", $sValue_arr[0], $count);
+			$sValue_arr[0] = str_replace("<div id='wrap' class='wrap'>", "", $sValue_arr[0], $count);
+			$sValue_arr[0] = str_replace("<div id=\"wrap\" class=\"wrap\">", "", $sValue_arr[0], $count);
+			if (strpos($sValue_arr[0], "<table width='100%' height='100%'>") !== false)
+				$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table width='100%' height='100%'>"), strlen("<table width='100%' height='100%'>"));
+			if (strpos($sValue_arr[0], "<table width=\"100%\" height=\"100%\">") !== false)
+				$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table width=\"100%\" height=\"100%\">"), strlen("<table width=\"100%\" height=\"100%\">"));
+			if (strpos($sValue_arr[0], "<table height='100%' width='100%'>") !== false)
+				$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table height='100%' width='100%'>"), strlen("<table height='100%' width='100%'>"));
+			if (strpos($sValue_arr[0], "<table height=\"100%\" width=\"100%\">") !== false)
+				$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<table height=\"100%\" width=\"100%\">"), strlen("<table height=\"100%\" width=\"100%\">"));
+			if (strpos($sValue_arr[0], "<tbody>") !== false)
+				$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<tbody>"), strlen("<tbody>"));
+			if (strpos($sValue_arr[0], "<tr>") !== false)
+				$sValue_arr[0] = substr_replace($sValue_arr[0], "", strpos($sValue_arr[0], "<tr>"), strlen("<tr>"));
+		}
 		if (($special != 1) || ($mode == "blog"))
 		{
 			$sValue_arr[0] = str_replace("<td valign='top' class='content_td' id='content_td'>", "", $sValue_arr[0], $count);
@@ -158,6 +165,11 @@
 			$sValue_arr[0] = str_replace("<div id='right_div' class='right_div'>", "", $sValue_arr[0], $count);
 			$sValue_arr[0] = str_replace("<div id=\"right_div\" class=\"right_div\">", "", $sValue_arr[0], $count);
 		}
+		elseif (substr($page_name, 0, 6) == "header")
+			$sValue_arr[0] = str_replace("<header>", "", $sValue_arr[0], $count);
+		elseif (substr($page_name, 0, 6) == "footer")
+			$sValue_arr[0] = str_replace("<footer>", "", $sValue_arr[0], $count);
+
 		$sValue_arr[0] = trim($sValue_arr[0]);
 		$sValue = $sValue_arr[0]. $sValue;
 		//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%//
@@ -182,18 +194,32 @@
 				if (strpos($sValue_arr[2], ">p<") !== false)
 					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">p<"), strlen(">p<"));
 			}
-			if (strpos($sValue_arr[2], ">vid/<") !== false)
-				$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">vid/<"), strlen(">vid/<"));
-			if (strpos($sValue_arr[2], ">elbat/<") !== false)
-				$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">elbat/<"), strlen(">elbat/<"));
-			if (strpos($sValue_arr[2], ">ydobt/<") !== false)
-				$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">ydobt/<"), strlen(">ydobt/<"));
-			if (strpos($sValue_arr[2], ">rt/<") !== false)
-				$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">rt/<"), strlen(">rt/<"));
-			if (strpos($sValue_arr[2], ">dt/<") !== false)
-				$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">dt/<"), strlen(">dt/<"));
-			if (strpos($sValue_arr[2], ">vid/<") !== false)
-				$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">vid/<"), strlen(">vid/<"));
+			if ( (substr($page_name, 0, 6) != "header") && (substr($page_name, 0, 6) != "footer") )
+			{
+				if (strpos($sValue_arr[2], ">vid/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">vid/<"), strlen(">vid/<"));
+				if (strpos($sValue_arr[2], ">elbat/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">elbat/<"), strlen(">elbat/<"));
+				if (strpos($sValue_arr[2], ">ydobt/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">ydobt/<"), strlen(">ydobt/<"));
+				if (strpos($sValue_arr[2], ">rt/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">rt/<"), strlen(">rt/<"));
+				if (strpos($sValue_arr[2], ">dt/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">dt/<"), strlen(">dt/<"));
+				if (strpos($sValue_arr[2], ">vid/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">vid/<"), strlen(">vid/<"));
+			}
+			elseif (substr($page_name, 0, 6) == "header")
+			{
+				if (strpos($sValue_arr[2], ">redaeh/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">redaeh/<"), strlen(">redaeh/<"));
+			}
+			elseif (substr($page_name, 0, 6) == "footer")
+			{
+				if (strpos($sValue_arr[2], ">retoof/<") !== false)
+					$sValue_arr[2] = substr_replace($sValue_arr[2], "", strpos($sValue_arr[2], ">retoof/<"), strlen(">retoof/<"));
+			}
+				
 			$sValue_arr[2] = strrev($sValue_arr[2]);
 			$sValue_arr[2] = trim($sValue_arr[2]);
 			$sValue .= $sValue_arr[2];
@@ -203,21 +229,35 @@
 //			fclose($fh);
 			//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%//
 		}
-		else	// Somehow CKEditor einter removed separator comment, or stuck bottom stuff to be removed above separator.
+		else	// Somehow CKEditor editer removed separator comment, or stuck bottom stuff to be removed above separator.
 		{		// Need to trim out end structures from main content.
 			$sValue = strrev($sValue);
-			if (strpos($sValue, ">vid/<") !== false)
-				$sValue = substr_replace($sValue, "", strpos($sValue, ">vid/<"), strlen(">vid/<"));
-			if (strpos($sValue, ">elbat/<") !== false)
-				$sValue = substr_replace($sValue, "", strpos($sValue, ">elbat/<"), strlen(">elbat/<"));
-			if (strpos($sValue, ">ydobt/<") !== false)
-				$sValue = substr_replace($sValue, "", strpos($sValue, ">ydobt/<"), strlen(">ydobt/<"));
-			if (strpos($sValue, ">rt/<") !== false)
-				$sValue = substr_replace($sValue, "", strpos($sValue, ">rt/<"), strlen(">rt/<"));
-			if (strpos($sValue, ">dt/<") !== false)
-				$sValue = substr_replace($sValue, "", strpos($sValue, ">dt/<"), strlen(">dt/<"));
-			if (strpos($sValue, ">vid/<") !== false)
-				$sValue = substr_replace($sValue, "", strpos($sValue, ">vid/<"), strlen(">vid/<"));
+			if ( (substr($page_name, 0, 6) != "header") && (substr($page_name, 0, 6) != "footer") )
+			{
+				if (strpos($sValue, ">vid/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">vid/<"), strlen(">vid/<"));
+				if (strpos($sValue, ">elbat/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">elbat/<"), strlen(">elbat/<"));
+				if (strpos($sValue, ">ydobt/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">ydobt/<"), strlen(">ydobt/<"));
+				if (strpos($sValue, ">rt/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">rt/<"), strlen(">rt/<"));
+				if (strpos($sValue, ">dt/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">dt/<"), strlen(">dt/<"));
+				if (strpos($sValue, ">vid/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">vid/<"), strlen(">vid/<"));
+			}
+			elseif (substr($page_name, 0, 6) == "header")
+			{
+				if (strpos($sValue, ">redaeh/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">redaeh/<"), strlen(">redaeh/<"));
+			}
+			elseif (substr($page_name, 0, 6) == "footer")
+			{
+				if (strpos($sValue, ">retoof/<") !== false)
+					$sValue = substr_replace($sValue, "", strpos($sValue, ">retoof/<"), strlen(">retoof/<"));
+			}
+			
 			$sValue = strrev($sValue);
 			$sValue = trim($sValue);
 			//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%//
